@@ -1,14 +1,13 @@
 #
-# $Id: STP.pm,v 1.2 2007/01/04 23:30:34 gomor Exp $
+# $Id: STP.pm 8 2015-01-14 06:55:14Z gomor $
 #
 package Net::Frame::Layer::STP;
-use strict;
-use warnings;
+use strict; use warnings;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use Net::Frame::Layer qw(:consts);
-require Exporter;
+use Exporter;
 our @ISA = qw(Net::Frame::Layer Exporter);
 
 our %EXPORT_TAGS = (
@@ -280,7 +279,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006-2007, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
